
A package containing modules used in teaching introductory programming (CSC 121) at Davidson College, Davidson, NC. It includes:
* a simple interface to read and write audio and image data (to facilitate the use of [media computation](http://coweb.cc.gatech.edu/mediaComp-teach) methods),
* a C-style `getch` function, and
* a wrapper for the [Twitter API](https://developer.twitter.com/en/docs.html).
